from django.db import models
from django.contrib.auth.models import User
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db.models.signals import pre_save
from django.dispatch import receiver
from django.core.validators import FileExtensionValidator
from django.utils.text import slugify
# Create your models here.

class ContactForm(models.Model):
    name = models.CharField(max_length=100)
    email = models.EmailField()
    phone_number = models.CharField(max_length=20)
    message = models.TextField()
    timestamp = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return self.name

class Blog(models.Model):
    title = models.CharField(max_length=200)
    short_description = models.CharField(max_length=400)
    content = models.TextField()
    image = models.ImageField(upload_to="Blog")
    publication_date = models.DateTimeField(auto_now_add=True)
    modified_date = models.DateTimeField(auto_now=True)
    slug = models.SlugField(unique=True,default="blog",max_length=255)

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return reverse('blog-detail', args=[self.slug])

class Link(models.Model):
    url = models.CharField(max_length=400)
    publication_date = models.DateTimeField(auto_now_add=True)
    modified_date = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.url

class Snippet(models.Model):
    title = models.CharField(max_length=150)
    slug = models.SlugField(blank=True,null=True)
    body = models.TextField()
    
    def __str__(self):
        return self.title

class Post(models.Model):
    title = models.CharField(max_length=100)
    content = models.TextField()
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)
    # Add any other fields you might have

    def __str__(self):
        return self.title

class Metadata(models.Model):
    title =models.TextField(blank=True,null=True)
    description = models.TextField(blank=True,null=True)
    keywords = models.TextField(blank=True,null=True)
    slug = models.SlugField(unique=True, blank=True, null=True)

    def __str__(self):
        return self.slug
